@@ -47,6 +47,7 @@
     * :meth:`AdbDevice.close`
     * :meth:`AdbDevice.connect`
     * :meth:`AdbDevice.list`
+    * :attr:`AdbDevice.max_chunk_size`
     * :meth:`AdbDevice.pull`
     * :meth:`AdbDevice.push`
     * :meth:`AdbDevice.root`
@@ -62,16 +63,15 @@
 
 import logging
 import os
-import socket
 import struct
 import time
 
 from . import constants
 from . import exceptions
-from .adb_message import AdbMessage, checksum, unpack
+from .adb_message import AdbMessage, checksum, int_to_cmd, unpack
 from .transport.base_transport import BaseTransport
 from .transport.tcp_transport import TcpTransport
-from .hidden_helpers import DeviceFile, _AdbTransactionInfo, _FileSyncTransactionInfo, get_files_to_push
+from .hidden_helpers import DeviceFile, _AdbTransactionInfo, _FileSyncTransactionInfo, get_banner, get_files_to_push
 
 try:
     from .transport.usb_transport import UsbTransport
@@ -112,16 +112,10 @@ class AdbDevice(object):
     """
 
     def __init__(self, transport, banner=None):
-        if banner:
-            if not isinstance(banner, (bytes, bytearray)):
-                self._banner = bytearray(banner, 'utf-8')
-            else:
-                self._banner = banner
+        if banner and not isinstance(banner, (bytes, bytearray)):
+            self._banner = bytearray(banner, 'utf-8')
         else:
-            try:
-                self._banner = bytearray(socket.gethostname(), 'utf-8')
-            except:  # noqa pylint: disable=bare-except
-                self._banner = bytearray('unknown', 'utf-8')
+            self._banner = banner
 
         if not isinstance(transport, BaseTransport):
             raise exceptions.InvalidTransportError("`transport` must be an instance of a subclass of `BaseTransport`")
@@ -208,6 +202,10 @@ class AdbDevice(object):
             Invalid auth response from the device
 
         """
+        # 0. Get `self._banner` if it was not provided in the constructor
+        if not self._banner:
+            self._banner = get_banner()
+
         # 1. Use the transport to establish a connection
         self._transport.close()
         self._transport.connect(transport_timeout_s)
@@ -757,13 +755,13 @@ class AdbDevice(object):
             command = constants.WIRE_TO_ID.get(cmd)
 
             if not command:
-                raise exceptions.InvalidCommandError('Unknown command: %x' % cmd, cmd, (arg0, arg1))
+                raise exceptions.InvalidCommandError("Unknown command: %d = '%s' (arg0 = %d, arg1 = %d, msg = '%s')" % (cmd, int_to_cmd(cmd), arg0, arg1, msg))
 
             if command in expected_cmds:
                 break
 
             if time.time() - start > adb_info.read_timeout_s:
-                raise exceptions.InvalidCommandError('Never got one of the expected responses (%s)' % expected_cmds, cmd, (adb_info.transport_timeout_s, adb_info.read_timeout_s))
+                raise exceptions.InvalidCommandError("Never got one of the expected responses: %s (transport_timeout_s = %d, read_timeout_s = %d" % (expected_cmds, adb_info.transport_timeout_s, adb_info.read_timeout_s))
 
         if data_length > 0:
             data = bytearray()
@@ -827,7 +825,7 @@ class AdbDevice(object):
                 break
 
             if time.time() - start > adb_info.read_timeout_s:
-                raise exceptions.InvalidCommandError('Never got one of the expected responses (%s)' % expected_cmds, cmd, (adb_info.transport_timeout_s, adb_info.read_timeout_s))
+                raise exceptions.InvalidCommandError("Never got one of the expected responses: %s (transport_timeout_s = %d, read_timeout_s = %d" % (expected_cmds, adb_info.transport_timeout_s, adb_info.read_timeout_s))
 
             # Ignore CLSE responses to previous commands
             # https://github.com/JeffLIrion/adb_shell/pull/14
@@ -845,12 +843,7 @@ class AdbDevice(object):
 
         1. Read the ``cmd`` and ``data`` fields from a ``b'CLSE'`` or ``b'WRTE'`` packet via :meth:`AdbDevice._read_until`
         2. If ``cmd`` is ``b'CLSE'``, then send a ``b'CLSE'`` message and stop
-        3. If ``cmd`` is not ``b'WRTE'``, raise an exception
-
-            * If ``cmd`` is ``b'FAIL'``, raise :class:`~adb_shell.exceptions.AdbCommandFailureException`
-            * Otherwise, raise :class:`~~adb_shell.exceptions.InvalidCommandError`
-
-        4. Yield ``data`` and repeat
+        3. Yield ``data`` and repeat
 
 
         Parameters
