@@ -45,6 +45,7 @@
     * :meth:`AdbDeviceAsync.close`
     * :meth:`AdbDeviceAsync.connect`
     * :meth:`AdbDeviceAsync.list`
+    * :attr:`AdbDeviceAsync.max_chunk_size`
     * :meth:`AdbDeviceAsync.pull`
     * :meth:`AdbDeviceAsync.push`
     * :meth:`AdbDeviceAsync.root`
@@ -57,14 +58,9 @@
 """
 
 
-try:
-    from asyncio import get_running_loop
-except ImportError:  # pragma: no cover
-    from asyncio import get_event_loop as get_running_loop  # Python 3.6 compatibility
-
+from asyncio import get_running_loop
 import logging
 import os
-import socket
 import struct
 import time
 
@@ -72,10 +68,10 @@ import aiofiles
 
 from . import constants
 from . import exceptions
-from .adb_message import AdbMessage, checksum, unpack
+from .adb_message import AdbMessage, checksum, int_to_cmd, unpack
 from .transport.base_transport_async import BaseTransportAsync
 from .transport.tcp_transport_async import TcpTransportAsync
-from .hidden_helpers import DeviceFile, _AdbTransactionInfo, _FileSyncTransactionInfo, get_files_to_push
+from .hidden_helpers import DeviceFile, _AdbTransactionInfo, _FileSyncTransactionInfo, get_banner, get_files_to_push
 
 
 _LOGGER = logging.getLogger(__name__)
@@ -111,17 +107,10 @@ class AdbDeviceAsync(object):
     """
 
     def __init__(self, transport, banner=None):
-        if banner:
-            if not isinstance(banner, (bytes, bytearray)):
-                self._banner = bytearray(banner, 'utf-8')
-            else:
-                self._banner = banner
+        if banner and not isinstance(banner, (bytes, bytearray)):
+            self._banner = bytearray(banner, 'utf-8')
         else:
-            try:
-                # TODO: make this async / don't do I/O
-                self._banner = bytearray(socket.gethostname(), 'utf-8')
-            except:  # noqa pylint: disable=bare-except
-                self._banner = bytearray('unknown', 'utf-8')
+            self._banner = banner
 
         if not isinstance(transport, BaseTransportAsync):
             raise exceptions.InvalidTransportError("`transport` must be an instance of a subclass of `BaseTransportAsync`")
@@ -208,6 +197,10 @@ class AdbDeviceAsync(object):
             Invalid auth response from the device
 
         """
+        # 0. Get `self._banner` if it was not provided in the constructor
+        if not self._banner:
+            self._banner = await get_running_loop().run_in_executor(None, get_banner)
+
         # 1. Use the transport to establish a connection
         await self._transport.close()
         await self._transport.connect(transport_timeout_s)
@@ -757,13 +750,13 @@ class AdbDeviceAsync(object):
             command = constants.WIRE_TO_ID.get(cmd)
 
             if not command:
-                raise exceptions.InvalidCommandError('Unknown command: %x' % cmd, cmd, (arg0, arg1))
+                raise exceptions.InvalidCommandError("Unknown command: %d = '%s' (arg0 = %d, arg1 = %d, msg = '%s')" % (cmd, int_to_cmd(cmd), arg0, arg1, msg))
 
             if command in expected_cmds:
                 break
 
             if time.time() - start > adb_info.read_timeout_s:
-                raise exceptions.InvalidCommandError('Never got one of the expected responses (%s)' % expected_cmds, cmd, (adb_info.transport_timeout_s, adb_info.read_timeout_s))
+                raise exceptions.InvalidCommandError("Never got one of the expected responses: %s (transport_timeout_s = %d, read_timeout_s = %d" % (expected_cmds, adb_info.transport_timeout_s, adb_info.read_timeout_s))
 
         if data_length > 0:
             data = bytearray()
@@ -827,7 +820,7 @@ class AdbDeviceAsync(object):
                 break
 
             if time.time() - start > adb_info.read_timeout_s:
-                raise exceptions.InvalidCommandError('Never got one of the expected responses (%s)' % expected_cmds, cmd, (adb_info.transport_timeout_s, adb_info.read_timeout_s))
+                raise exceptions.InvalidCommandError("Never got one of the expected responses: %s (transport_timeout_s = %d, read_timeout_s = %d" % (expected_cmds, adb_info.transport_timeout_s, adb_info.read_timeout_s))
 
             # Ignore CLSE responses to previous commands
             # https://github.com/JeffLIrion/adb_shell/pull/14
@@ -845,12 +838,7 @@ class AdbDeviceAsync(object):
 
         1. Read the ``cmd`` and ``data`` fields from a ``b'CLSE'`` or ``b'WRTE'`` packet via :meth:`AdbDeviceAsync._read_until`
         2. If ``cmd`` is ``b'CLSE'``, then send a ``b'CLSE'`` message and stop
-        3. If ``cmd`` is not ``b'WRTE'``, raise an exception
-
-            * If ``cmd`` is ``b'FAIL'``, raise :class:`~adb_shell.exceptions.AdbCommandFailureException`
-            * Otherwise, raise :class:`~~adb_shell.exceptions.InvalidCommandError`
-
-        4. Yield ``data`` and repeat
+        3. Yield ``data`` and repeat
 
 
         Parameters
